summaryrefslogtreecommitdiffstats
path: root/src/k3bfiletreecombobox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/k3bfiletreecombobox.cpp')
-rw-r--r--src/k3bfiletreecombobox.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/k3bfiletreecombobox.cpp b/src/k3bfiletreecombobox.cpp
index 35578c5..88a835c 100644
--- a/src/k3bfiletreecombobox.cpp
+++ b/src/k3bfiletreecombobox.cpp
@@ -198,7 +198,7 @@ void K3bFileTreeComboBox::popdown()
{
m_fileTreeView->hide();
d->poppedUp = false;
- tqrepaint(); // tqrepaint the arrow
+ repaint(); // repaint the arrow
}
@@ -318,7 +318,7 @@ void K3bFileTreeComboBox::mousePressEvent( TQMouseEvent* e )
if ( arrowRect.contains( e->pos() ) ) {
popup();
- tqrepaint( FALSE );
+ repaint( FALSE );
}
}